"use strict";

Object.defineProperty(exports, "__esModule", {
    value: true
});
var multipliers = exports.multipliers = {
    HUNDRED: 100,
    THOUSAND: 1000,
    MILLION: 1000000,
    BILLION: 1000000000
};

var numbers = exports.numbers = {
    ZERO: 0,
    ONE: 1,
    TWO: 2,
    THREE: 3,
    FOUR: 4,
    FIVE: 5,
    SIX: 6,
    SEVEN: 7,
    EIGHT: 8,
    NINE: 9,
    TEN: 10,
    ELEVEN: 11,
    TWELVE: 12,
    THIRTEEN: 13,
    FOURTEEN: 14,
    FIFTEEN: 15,
    SIXTEEN: 16,
    SEVENTEEN: 17,
    EIGHTEEN: 18,
    NINETEEN: 19,
    TWENTY: 20,
    THIRTY: 30,
    FOURTY: 40,
    FIFTY: 50,
    SIXTY: 60,
    SEVENTY: 70,
    EIGHTY: 80,
    NINETY: 90
};

var units = exports.units = {
    SECONDS: 1000,
    MINUTES: 1000 * 60,
    HOURS: 1000 * 60 * 60,
    DAYS: 1000 * 60 * 60 * 24,
    WEEKS: 1000 * 60 * 60 * 24 * 7
};

Object.assign(units, {
    SECOND: units.SECONDS,
    MINUTE: units.MINUTES,
    HOUR: units.HOURS,
    DAY: units.DAYS,
    WEEK: units.WEEKS
});
'use strict';

Object.defineProperty(exports, "__esModule", {
    value: true
});

var _constants = require('./constants');

exports.default = new Proxy({}, {
    get: function get(target, name) {
        return find(name);
    }
});


var isNumber = function isNumber(token) {
    return _constants.numbers[token] !== undefined;
};
var isMultiplier = function isMultiplier(token) {
    return _constants.multipliers[token] !== undefined;
};
var isUnit = function isUnit(token) {
    return _constants.units[token] !== undefined;
};

function parse(token) {
    if (isNumber(token)) {
        return { type: 'number', value: _constants.numbers[token] };
    }
    if (isMultiplier(token)) {
        return { type: 'multiplier', value: _constants.multipliers[token] };
    }
    if (isUnit(token)) {
        return { type: 'unit', value: _constants.units[token] };
    }
    throw new Error('Could not parse expression ' + token + '.');
}

function find(name) {
    var terms = name.split('_').map(function (term) {
        return term.toUpperCase();
    }).filter(function (term) {
        return term !== 'AND';
    }).map(parse);

    var sum = 0;
    var partSum = 0;

    for (var i = 0; i < terms.length; i++) {
        var term = terms[i];

        switch (term.type) {
            case 'number':
                {
                    partSum += term.value;
                    break;
                }
            case 'multiplier':
                {
                    partSum = (partSum || 1) * term.value;
                    break;
                }
            case 'unit':
                {
                    sum = sum + partSum * term.value;
                    partSum = 0;
                    break;
                }
        }
    }

    return partSum + sum;
}
